import sys

import pygame
import pygame.locals as pgl

from naja.constants import SCREEN
from naja.engine import Engine
from naja.sound import sound
from naja.options import parse_args, options
from naja.resources.loader import Loader
from naja.scenes.menu import MenuScene
from naja.utils import warp_to_game_state


def main():
    '''Launch the naja'''
    parse_args(sys.argv)
    pygame.display.init()
    pygame.font.init()

    # set_icon needs to be called before set_mode on some platforms, but we
    # can't use convert_alpha until we've created a window with set_mode
    r = Loader('data')
    r.CONVERT_ALPHA = False
    if sys.platform == 'darwin':
        # OSX accepts big icons, but scales up small icons smoothly
        icon_size = 512
    elif sys.platform == 'win32':
        # It's corrupted at any smaller size. And crashes, at larger sizes.
        icon_size = 32
    else:
        icon_size = 24
    pygame.display.set_icon(
        r.get_image('robot_%i.png' % icon_size, basedir='icons'))

    pygame.display.set_mode(SCREEN, pgl.SWSURFACE)
    pygame.display.set_caption('Robolock II')
    sound.init()

    screen = pygame.display.get_surface()
    scene = MenuScene(None)
    engine = Engine(screen, scene, None)

    if options.game_state is not None:
        warp_to_game_state(options.game_state)

    engine.run()


if __name__ == '__main__':
    main()
