"""
The current game state.
"""

from naja.gameboard import GameBoard
from naja.resources import resources, ResourceNotFound


def load_location_deck(name):
    try:
        return resources.get_yaml('location_decks', '%s.yaml' % name)
    except ResourceNotFound:
        return resources.get_json('location_decks', '%s.json' % name)


class GameState(object):
    """
    Naja game state.
    """

    def __init__(self, gameboard):
        self.gameboard = gameboard

    @classmethod
    def new(cls, deck='standard', **kw):
        deck = load_location_deck(deck)
        return cls(GameBoard.new_game(deck, **kw))

    @classmethod
    def load(cls, data):
        return cls(GameBoard.import_game(data))

    @property
    def player(self):
        return self.gameboard.player

    @property
    def board_locations(self):
        return self.gameboard.board_locations
