'''Mutations to apply to images'''

from pygame.transform import flip, rotate, scale

from naja.constants import EIGHT_BIT_SCALE

from pygame import surface
import pygame.locals as pgl


class Mutator(object):
    def __init__(self, func, *args):
        self._func = func
        self._args = tuple(args)

    def __call__(self, image):
        return self._func(image, *self._args)

    def __hash__(self):
        return hash((self._func, self._args))

    def __eq__(self, other):
        if not isinstance(other, Mutator):
            return NotImplemented
        return (self._func == other._func) and (self._args == other._args)

    def __repr__(self):
        return '<%s %r>' % (self.__class__.__name__, self._args)


def rotator(angle):
    return Mutator(rotate, angle)


def scaler(size):
    return Mutator(scale, size)


def scale_multiplier(image, factor):
    size = image.get_width() * factor, image.get_height() * factor
    return scale(image, size)


def blend_add(image, colour, flags=pgl.BLEND_ADD):
    """Overlay the image with the given colour using BLEND_ADD"""
    blend = surface.Surface(image.get_size())
    blend.fill(colour)
    # We return a copy
    blended_image = image.copy()
    blended_image.blit(blend, (0, 0), special_flags=flags)
    return blended_image


def blender(colour, flags=pgl.BLEND_ADD):
    return Mutator(blend_add, tuple(colour), flags)


# Identity mutator
NULL = Mutator(lambda x: x)

# Rotation
R90 = rotator(90)
R180 = rotator(180)
R270 = rotator(-90)

FLIP_H = Mutator(flip, True, False)
FLIP_V = Mutator(flip, False, True)

EIGHT_BIT = Mutator(scale_multiplier, EIGHT_BIT_SCALE)
