"""
Main menu scene.
"""

import pygame.locals as pgl

from naja.constants import KEYS, PALETTE, KONAMI_CODE
from naja.events import SceneChangeEvent, QuitGameEvent
from naja.options import options
from naja.scenes.scene import Scene
from naja.scenes.credits import CreditsScene
from naja.scenes.game import GameScene
from naja.scenes.introduction import IntroductionScene
from naja.scenes.load_save import LoadGameScene, SaveGameScene
from naja.scenes.new_game import NewGameScene
from naja.scenes.puzzlelist import PuzzleListScene
from naja.widgets.selector import SelectorWidget
from naja.widgets.text import TextWidget
from naja.widgets.image_box import ImageBox
from naja.sound import sound


class MenuScene(Scene):
    def __init__(self, state):
        super(MenuScene, self).__init__(state)

        background = ImageBox(
            (0, 0), "screens/splash.png")
        self.add(background)

        selector = SelectorWidget()
        self.add(selector)
        y_offset, y_diff = 270, 36
        x_offset = 400

        y_offset += y_diff
        intro = TextWidget(
            (x_offset, y_offset), 'Introduction', colour=PALETTE.WHITE,
            centre=True)
        intro.add_callback('click', self.scene_callback(IntroductionScene))
        selector.add(intro)

        y_offset += y_diff
        resume = TextWidget(
            (x_offset, y_offset), 'Resume Game', colour=PALETTE.WHITE,
            unselectable_colour=PALETTE.GREY, centre=True)
        resume.add_callback('click', self.scene_callback(GameScene))
        resume.set_selectable_callback(lambda: state is not None)
        selector.add(resume)

        if state is None:
            selector.position = 2
        else:
            selector.position = 1

        y_offset += y_diff
        new = TextWidget(
            (x_offset, y_offset), 'New Random Game', colour=PALETTE.WHITE,
            centre=True)
        new.add_callback('click', self.scene_callback(NewGameScene))
        selector.add(new)

        y_offset += y_diff
        new = TextWidget(
            (x_offset, y_offset), 'New Puzzle', colour=PALETTE.WHITE,
            centre=True)
        new.add_callback('click', self.scene_callback(PuzzleListScene))
        selector.add(new)

        y_offset += y_diff
        load = TextWidget(
            (x_offset, y_offset), 'Load Game', colour=PALETTE.WHITE,
            centre=True)
        load.add_callback('click', self.scene_callback(LoadGameScene))
        selector.add(load)

        y_offset += y_diff
        save = TextWidget(
            (x_offset, y_offset), 'Save Game', colour=PALETTE.WHITE,
            unselectable_colour=PALETTE.GREY, centre=True)
        save.add_callback('click', self.scene_callback(SaveGameScene))
        save.set_selectable_callback(lambda: state is not None)
        selector.add(save)

        y_offset += y_diff
        credits = TextWidget(
            (x_offset, y_offset), 'Credits', colour=PALETTE.WHITE,
            centre=True)
        credits.add_callback('click', self.scene_callback(CreditsScene))
        selector.add(credits)

        y_offset += y_diff
        quit = TextWidget((x_offset, y_offset), 'Quit', colour=PALETTE.WHITE,
                          centre=True)
        quit.add_callback('click', lambda event: QuitGameEvent.post())
        selector.add(quit)

        self.konami = []
        if not sound.playing_music:
            sound.play_music('scape.ogg', 0.25)

    def scene_callback(self, scene_class):
        return lambda event: SceneChangeEvent.post(scene_class)

    def handle_event(self, ev):
        if ev.type == pgl.KEYDOWN and self.konami is not None:
            if ev.key in KEYS.KONAMI:
                self.konami.append(ev.key)
                if self.konami == KONAMI_CODE:
                    options['cheat_enabled'] = True
                    print "Cheats enabled."
                    print "  Try hitting some number keys."
                    self.konami = None
                elif self.konami != KONAMI_CODE[:len(self.konami)]:
                    self.konami = None
        return super(MenuScene, self).handle_event(ev)

    def handle_scene_event(self, ev):
        if ev.type == pgl.KEYDOWN:
            if ev.key in KEYS.QUIT:
                QuitGameEvent.post()
                return
