"""
Load and save scenes.
"""

import pygame.locals as pgl

from naja.constants import KEYS
from naja.events import SceneChangeEvent, LoadGameEvent
from naja.gamestate import GameState
from naja.scenes.scene import Scene
from naja.widgets.image_box import ImageBox
from naja.widgets.selector import SelectorWidget
from naja.widgets.text import TextWidget


class NewGameScene(Scene):
    def __init__(self, state):
        super(NewGameScene, self).__init__(state)

        background = ImageBox(
            (0, 0), "screens/splash.png")
        self.add(background)

        selector = SelectorWidget()
        selector.position = 1
        self.add(selector)

        y_offset, y_diff = 270, 40
        x_offset = 400

        y_offset += y_diff
        title = TextWidget(
            (x_offset, y_offset), 'NEW GAME', colour='white',
            centre=True)
        self.add(title)

        y_offset += y_diff
        question = TextWidget(
            (x_offset, y_offset), 'Select difficulty:', colour='white',
            centre=True)
        self.add(question)

        y_offset += y_diff
        easy = TextWidget(
            (x_offset, y_offset), 'Easy', fontsize=32, colour='white',
            centre=True)
        easy.add_callback('click', self.easy_game)
        selector.add(easy)

        y_offset += y_diff
        standard = TextWidget(
            (x_offset, y_offset), 'Standard', fontsize=32, colour='white',
            centre=True)
        standard.add_callback('click', self.standard_game)
        selector.add(standard)

        y_offset += y_diff
        hard = TextWidget(
            (x_offset, y_offset), 'Hard', fontsize=32, colour='white',
            centre=True)
        hard.add_callback('click', self.hard_game)
        selector.add(hard)

        y_offset += y_diff
        very_hard = TextWidget(
            (x_offset, y_offset), 'Very Hard', fontsize=32, colour='white',
            centre=True)
        very_hard.add_callback('click', self.very_hard_game)
        selector.add(very_hard)

        y_offset += y_diff
        nintendo = TextWidget(
            (x_offset, y_offset), 'NINTENDO Hard', fontsize=32, colour='white',
            centre=True)
        nintendo.add_callback('click', self.nintendo_hard_game)
        selector.add(nintendo)

    def easy_game(self, event):
        self.start_game(GameState.new(max_health=5, wins_required=3))

    def standard_game(self, event):
        self.start_game(GameState.new(max_health=4, wins_required=4))

    def hard_game(self, event):
        self.start_game(GameState.new(max_health=3, wins_required=5))

    def very_hard_game(self, event):
        self.start_game(GameState.new(max_health=2, wins_required=6))

    def nintendo_hard_game(self, event):
        self.start_game(GameState.new(max_health=1, wins_required=7))

    def start_game(self, state):
        from naja.scenes.game import GameScene
        LoadGameEvent.post(state=state)
        SceneChangeEvent.post(GameScene)

    def handle_scene_event(self, ev):
        if ev.type == pgl.KEYDOWN and ev.key in KEYS.QUIT:
            from naja.scenes.menu import MenuScene
            SceneChangeEvent.post(MenuScene)
            return
