"""
Widget that holds the games's bits.
"""

import pygame

from naja.constants import BIT_SIZE
from naja.resources import resources
from naja.resources.mutators import EIGHT_BIT
from naja.widgets.base import Widget
from naja.widgets.text import TextWidget


class GameBitsWidget(Widget):
    """
    Widget which holds the game's bits.
    """
    def __init__(self, pos, state):
        super(GameBitsWidget, self).__init__(pos, BIT_SIZE)
        self.state = state

    def prepare(self):
        self.surface = pygame.Surface(BIT_SIZE)

        size = BIT_SIZE[1]

        zero = TextWidget((0, 0), '0', fontsize=24, colour='white')
        one = TextWidget((0, 0), '1', fontsize=24, colour='white')
        zero.prepare()
        zero.pos = (0, (size - zero.size[1]))
        one.pos = zero.pos

        health = self.state.gameboard.health
        max_health = self.state.gameboard.max_health
        wins = self.state.gameboard.wins
        wins_required = self.state.gameboard.wins_required

        bits = []
        bits.extend((i < health, 'health') for i in range(max_health))
        bits.extend((i < wins, 'win') for i in range(wins_required))

        for pos, (is_set, image) in enumerate(bits):
            img = resources.get_image(
                'bits', '%s_%s.png' % (image, 'on' if is_set else 'off'),
                transforms=(EIGHT_BIT,))
            self.surface.blit(img, (img.get_width() * pos, 0))
            if is_set:
                one.render(self.surface)
            else:
                zero.render(self.surface)
            one.pos = zero.pos = (zero.pos[0] + size, zero.pos[1])

    def draw(self, surface):
        surface.blit(self.surface, self.pos)
