"""Widget to draw an image"""

from naja.resources import resources
from naja.resources.mutators import EIGHT_BIT
from naja.widgets.base import Widget


class ImageBox(Widget):
    """Widget which holds an image."""

    def __init__(self, pos, image, eight_bit=True, transforms=()):
        super(ImageBox, self).__init__(pos)
        self.image = image
        if eight_bit:
            transforms = (EIGHT_BIT,) + transforms
        self.transforms = transforms

    def prepare(self):
        self.surface = resources.get_image(
            self.image, transforms=self.transforms)
        self.size = self.surface.get_rect().size

    def draw(self, surface):
        surface.blit(self.surface, self.rect)


class PreRenderedImageBox(Widget):
    """Hold an image given as a surface"""

    def __init__(self, pos, image):
        super(PreRenderedImageBox, self).__init__(pos)
        self.surface = image

    def prepare(self):
        self.size = self.surface.get_rect().size

    def draw(self, surface):
        surface.blit(self.surface, self.rect)

