import pygame

from naja.constants import BITS, PALETTE
from naja.widgets.base import Widget
from naja.widgets.text import TextWidget, TextBoxWidget


class SaveSlotWidget(Widget):
    """
    Widget for displaying a save slot.
    """
    def __init__(self, pos, slot, game_data):
        super(SaveSlotWidget, self).__init__(pos, (600, 64))
        self.slot = slot
        self.game_data = game_data

    def prepare(self):
        self.surface = pygame.surface.Surface(self.size)
        header = self.get_slot_header()
        name_text = "Slot %s: %s" % (self.slot, header)
        name = TextWidget((0, 0), name_text, colour=PALETTE.WHITE)
        name.render(self.surface)
        self.prepare_game_state()

    def get_slot_header(self):
        if self.game_data is None:
            return "--"
        else:
            return self.game_data['timestamp']

    def render_state_glyph(self, x_offset, text, colour):
        widget = TextBoxWidget(
            (x_offset, 32), text, box_width=32, colour=colour,
            bg_colour=PALETTE.BLACK)
        widget.render(self.surface)

    def prepare_game_state(self):
        if self.game_data is None:
            state_text = TextWidget((32, 32), '-EMPTY-', colour=PALETTE.WHITE)
            state_text.render(self.surface)
        else:
            state_data = self.game_data['data']
            x_offset = 0

            for i in range(state_data['max_health']):
                x_offset += 32
                if i < state_data['health']:
                    colour = PALETTE.PINK
                else:
                    colour = PALETTE.DARK_RED
                self.render_state_glyph(x_offset, '{HEALTH_NOCOLOUR}', colour)

            for i in range(state_data['wins_required']):
                x_offset += 32
                if i < state_data['wins']:
                    colour = PALETTE.LIGHT_TURQUOISE
                else:
                    colour = PALETTE.DARK_OLIVE
                self.render_state_glyph(
                    x_offset, '{WINTOKEN_NOCOLOUR}', colour)

            x_offset += 64
            bit_names = dict((v, k) for k, v in BITS.items())
            player_bits = state_data['player']['bits']
            for bit in reversed(range(8)):
                x_offset += 32
                if (1 << bit) & player_bits:
                    text = '{%s}' % (bit_names[bit],)
                    self.render_state_glyph(x_offset, text, PALETTE.GREY)

    def draw(self, surface):
        surface.blit(self.surface, self.pos)
